import request from '@/utils/request'

// 查询数据接口api配置列表
export function listAPICONFIG(query) {
  return request({
    url: '/APICONFIG/list',
    method: 'get',
    params: query
  })
}

// 查询数据接口api配置所有列表
export function listAllAPICONFIG(query) {
  return request({
    url: '/APICONFIG/listAll',
    method: 'get',
    params: query
  })
}

// 查询数据接口api配置详细
export function getAPICONFIG(id) {
  return request({
    url: '/APICONFIG/getInfo/' + id,
    method: 'get'
  })
}

// 新增数据接口api配置
export function addAPICONFIG(data) {
  return request({
    url: '/APICONFIG/add',
    method: 'post',
    data: data
  })
}

// 修改数据接口api配置
export function updateAPICONFIG(data) {
  return request({
    url: '/APICONFIG/edit',
    method: 'post',
    data: data
  })
}

// 删除数据接口api配置
export function delAPICONFIG(id) {
  return request({
    url: '/APICONFIG/remove/' + id,
    method: 'get'
  })
}
//导出
export function exportAPICONFIG(id) {
  return request({
    url: '/APICONFIG/export/' + id,
    method: 'post',
    responseType: "blob"
  })


}//导入
export function uploadAPICONFIG(file) {
  return request({
    url: '/APICONFIG/upload/',
    method: 'post',
    data:file
  })
  
}


// // 导入
// export function upload(data) {
//   return request({
//     url: '/common/upload/',
//     method: 'post',
//     data:data
//   })
// }